@@ -1,4 +1,5 @@
 use crate::Config;
+use std::net::IpAddr;
 use trillium::{async_trait, Handler};
 use trillium_http::transport::Transport;
 use trillium_tls_common::Acceptor;
@@ -14,6 +15,13 @@ pub trait Server: Sized {
     */
     type Transport: Transport;
 
+    /**
+    Determine the remote ip/port for the Transport.
+    */
+    fn peer_ip(_transport: &Self::Transport) -> Option<IpAddr> {
+        None
+    }
+
     /**
     entrypoint to run a handler with a given config. if this function
     is called, it is safe to assume that we are not yet within an
